@@ -9,15 +9,17 @@ use English qw( -no_match_vars );
 use if !defined @ISA, Devel::Trepan::CmdProcessor::Command ;
 
 unless (defined @ISA) {
-    eval "use constant CATEGORY   => 'data';";
-    eval "use constant NEED_STACK => 0;";
-    eval "use constant SHORT_HELP => 'Cancel some expressions to be displayed when program stops';"
+    eval <<'EOE';
+use constant CATEGORY   => 'data';
+use constant NEED_STACK => 0;;
+use constant SHORT_HELP => 'Cancel some expressions to be displayed when program stops';
+use constant MIN_ARGS   => 0;     # Need at least this many
+use constant MAX_ARGS   => undef; # Need at most this many - undef -> unlimited.
+EOE
 }
 
 use strict; use vars qw(@ISA); @ISA = @CMD_ISA;
 use vars @CMD_VARS;  # Value inherited from parent
-our $MIN_ARGS   = 0;      # Need at least this many
-our $MAX_ARGS   = undef;  # Need at most this many - undef -> unlimited.
 
 our $NAME = set_name();
 our $HELP = <<"HELP";
