@@ -56,7 +56,7 @@ sub run($$) {
 	# FIXME: handle someday...
 	# my $cmd_name = $args->[0];
 	# my $opts->{return_type} = parse_eval_suffix($cmd_name);
-	my $opts->{return_type} = '$';
+	my $opts = {return_type => '$'}; 
 	my $mess = sprintf("Watch expression %d `%s' set", $wp->id, $expr);
 	$proc->msg($mess);
 	$proc->evaluate($expr, $opts);
